
// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import Process 0.1
import FileIO 1.0
import ".."
import VLCVideo 1.0

Rectangle {
    id: root

    property string cursorState: "Firmware"
    property bool viewSelected: diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0
    property bool firmwareReady: serialTuner.availableFirmwareVersion !== "" && serialTuner.availableFirmwareVersion !== "0.0" && serialTuner.availableFirmwareVersion !== "255.255"
    property string firmwareVersion: serialTuner.firmwareVersion
    property string availableFirmwareVersion: serialTuner.availableFirmwareVersion
    property bool blocking: serialTuner.loadingFirmware

    function expectedFilename() {
        switch (serialTuner.cardModel) {
            case "TM017":
                return "TM017.bin"
            case "TM016":
                return "TM016.bin"
            default: {
                console.log("!! Warning: Invalid tuner model", serialTuner.cardModel)
                return "invalid_ShouldNotBeUpdated.bin"
            }
        }
    }

    anchors.fill: parent
    width: 1366
    height: 768
    color: "transparent"

    Text {
        id: displayFirmwareVersion
        text: qsTr("Current Firmware Version") + ": " + firmwareVersion + application.emptyString
        anchors.left: parent.left
        anchors.leftMargin: 38
        anchors.top: parent.top
        anchors.topMargin: 50
    }

    ImageButton {
        id: firmwareLoadButton

        Connections {
            target: root.viewSelected && !root.blocking ? keymapper : null
            onEnter2Pressed: {
                main.debugKeys("enter2Pressed", "DiagnosticsTVAdvancedSerial")
                firmwareLoadButton.clicked()
            }
        }

        enabled: !serialTuner.checkingFirmware && !serialTuner.loadingFirmware
        label: root.firmwareReady ? qsTr("Load Firmware ") + serialTuner.availableFirmwareVersion : qsTr("Check for Firmware")
        label_under: true
        label_color: "black"
        upimage:"./graphics/200/TRU_200_other_small_Button_Up.png"
        downimage:"./graphics/200/TRU_200_other_small_Button_Down.png"
        anchors.left: parent.left
        anchors.leftMargin: 80
        anchors.top: parent.top
        anchors.topMargin: 120
        onClicked: {
            if (root.firmwareReady) {
                serialTuner.startFirmwareLoad(expectedFilename())
            } else {
                serialTuner.checkForAvailableFirmware(expectedFilename())
            }
        }
    }

    Image {
        id: firmwareLoadCursor
        source: "../graphics/tft/NAV_selector_2.png"
        visible: root.viewSelected && cursorState === "Firmware" && !serialTuner.loadingFirmware && serialTuner.initialized
        anchors.verticalCenter: firmwareLoadButton.verticalCenter
        anchors.horizontalCenter: firmwareLoadButton.horizontalCenter
        anchors.horizontalCenterOffset: -44
        z: firmwareLoadButton.z - 1
    }

    MessagePopup {
        id: firmwareLoadErrorPopup
        message: qsTr("Firmware Load Error") + application.emptyString
    }

    MessagePopup {
        id: firmwareSuccessPopup
        message: qsTr("Firmware Updated") + application.emptyString
    }

    MessagePopup {
        id: firmwareLoadingPopup
        message: qsTr("Loading Firmware ") + root.availableFirmwareVersion + application.emptyString
    }

    Connections {
        target: serialTuner
        onFirmwareLoadError: {
            firmwareLoadingPopup.hide()
            firmwareLoadErrorPopup.showWithTimeout(3)
        }
        onFirmwareUpdateStarted: {
            tv.mrl = tv.channelList.getOnscreenDisplayMrl()
            firmwareLoadingPopup.showWithTimeout(3)
        }

        onFirmwareUpdateFinished: {
            firmwareLoadingPopup.hide()
            firmwareSuccessPopup.showWithTimeout(3)
            main.restartRequired = true
        }
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && root.viewSelected ? keymapper : null

        onBackPressed: {
            if (serialTuner.loadingFirmware) {
                return
            }

            main.debugKeys("backPressed", "DiagnosticsTVAdvancedSerial")
            diagnostics_screen.item.unselectScreen()
        }
    }

    VLCSurface {
        id: onScreenDisplay
        visible: serialTuner.loadingFirmware
        player: tv.player
        aspect: tv.aspect
        playing: 1
        width: parent.width * 0.5
        height: width/tv.aspect
        anchors.centerIn: parent
        onPlayingChanged: tv.on = playing
        z: 1000
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && root.viewSelected && !root.blocking && !serialTuner.loadingFirmware

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: {
            if (cursorState === "Firmware") {
                return qsTr("press ENTER to select") + application.emptyString
            }
            return ""
        }
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }

    Component.onCompleted: {
        if (!serialTuner.initialized) {
            notYetInitializedMessage.show()
        }

        if (serialTuner.initialized) {
            serialTuner.checkForAvailableFirmware(expectedFilename())
        }
    }

    MessagePopup {
        id: notYetInitializedMessage
        message: qsTr("Tuner not initialized") + application.emptyString
    }
}
